diff --git a/productMods/js/menupage/browseClassGroupsPiePeople.js b/productMods/js/menupage/browseClassGroupsPiePeople.js
deleted file mode 100644
index 4a1acc61..00000000
--- a/productMods/js/menupage/browseClassGroupsPiePeople.js
+++ /dev/null
@@ -1,39 +0,0 @@
-/* $This file is distributed under the terms of the license in /doc/license.txt$ */
-
-// This file extends and proxies the default behavior defined in vitro/webapp/web/js/menupage/browseByClassGroupsPie.js
-
-// Saving the original graphClasses function from browseClassGroups
-var graphPersonClasses = graphClasses.piechart;
-
-// Assigning the proxy function
-graphClasses.piechart = function(values, labels, uris) {
- // Clear the existing pie chart
- $('#menupage-graph').empty();
-
- // Create the canvas
- var r = Raphael("menupage-graph", 360, 360);
-
- // Setup the colors for the slices
- // colors = ['#192933', '#26404E', '#294656', '#194c68', '#487A96', '#63A8CE', '#67AED6','#758A96', '#9DB9C9' ];
- colors = ['#143D52', '#1F5C7A', '#297AA3', '#3399CC', '#5CADD6', '#85C2E0', '#ADD6EB', '#ADCBDD', '#D6EBF5', '#E9F1F5' ];
- // Reverse colors to see how it looks with larger slices in lighter hues:
- // colors = colors.reverse();
-
- // Now draw the pie chart
- var pie = r.g.piechart(110, 120, 100, values, {legend: labels, legendmark: "square", legendpos: "south", colors: colors});
- pie.hover(function () {
- this.sector.stop();
- this.sector.scale(1.1, 1.1, this.cx, this.cy);
- if (this.label) {
- this.label[0].stop();
- this.label[0].scale(1.5);
- this.label[1].attr({"font-weight": 800});
- }
- }, function () {
- this.sector.animate({scale: [1, 1, this.cx, this.cy]}, 500, "bounce");
- if (this.label) {
- this.label[0].animate({scale: 1}, 500, "bounce");
- this.label[1].attr({"font-weight": 400});
- }
- });
-};
\ No newline at end of file
diff --git a/productMods/templates/freemarker/body/menupage/menupage--classgroup-people.ftl b/productMods/templates/freemarker/body/menupage/menupage--classgroup-people.ftl
index 7b182dd9..e84bcf5a 100644
--- a/productMods/templates/freemarker/body/menupage/menupage--classgroup-people.ftl
+++ b/productMods/templates/freemarker/body/menupage/menupage--classgroup-people.ftl
@@ -3,28 +3,18 @@
<#include "menupage-checkForData.ftl">
<#if !noData>
-
diff --git a/productMods/js/menupage/browseByVClassPeople.js b/productMods/js/menupage/browseByVClassPeople.js
index 57891936..a6c84063 100644
--- a/productMods/js/menupage/browseByVClassPeople.js
+++ b/productMods/js/menupage/browseByVClassPeople.js
@@ -20,7 +20,8 @@ browseByVClass.getIndividuals = function(vclassUri, alpha, page, scroll) {
scroll = true;
}
- // First wipe currently displayed individuals and existing pagination
+ // First wipe currently displayed class heading, individuals, and existing pagination
+ $('h3.selected-class').remove();
this.individualsInVClass.empty();
$('nav.pagination').remove();
@@ -31,6 +32,9 @@ browseByVClass.getIndividuals = function(vclassUri, alpha, page, scroll) {
browseByVClass.pagination(pages, page);
}
+ selectedClassHeading = '
'+ results.vclass.name +'
';
+ browseByVClass.individualsContainer.prepend(selectedClassHeading);
+
$.each(results.individuals, function(i, item) {
label = results.individuals[i].label;
firstName = results.individuals[i].firstName;
@@ -52,7 +56,6 @@ browseByVClass.getIndividuals = function(vclassUri, alpha, page, scroll) {
} else {
preferredTitle = results.individuals[i].preferredTitle;
}
- // preferredTitle = results.individuals[i].preferredTitle;
uri = results.individuals[i].URI;
profileUrl = results.individuals[i].profileUrl;
if ( !results.individuals[i].thumbUrl ) {
@@ -76,9 +79,9 @@ browseByVClass.getIndividuals = function(vclassUri, alpha, page, scroll) {
browseByVClass.selectedVClass(results.vclass.URI);
browseByVClass.selectedAlpha(alpha);
// Scroll to the top of the browse section unless told otherwise
if ( scroll != false ) {
- $.scrollTo('#browse-by', 500);
+ $.scrollTo('#menupage-intro', 500);
}
});
};
@@ -76,9 +79,9 @@ browseByVClass.getIndividuals = function(vclassUri, alpha, page, scroll) {
browseByVClass.selectedVClass(results.vclass.URI);
browseByVClass.selectedAlpha(alpha);
- // Scroll to the top of the browse section unless told otherwise
+ // Scroll to #menupage-intro unless told otherwise
if ( scroll != false ) {
\ No newline at end of file